@@ -1,10 +1,4 @@
 import argparse
-import os
-
-from mitmproxy.addons import core
-
-
-CONFIG_PATH = os.path.join(core.CA_DIR, "config.yaml")
 
 
 def common_options(parser, opts):
@@ -24,12 +18,6 @@ def common_options(parser, opts):
         action='store_true',
         help="Show all commands and their signatures",
     )
-    parser.add_argument(
-        "--conf",
-        type=str, dest="conf", default=CONFIG_PATH,
-        metavar="PATH",
-        help="Read options from a configuration file"
-    )
     parser.add_argument(
         "--set",
         type=str, dest="setoptions", default=[],
@@ -69,6 +57,7 @@ def common_options(parser, opts):
     opts.make_parser(group, "listen_port", metavar="PORT", short="p")
     opts.make_parser(group, "server", short="n")
     opts.make_parser(group, "ignore_hosts", metavar="HOST")
+    opts.make_parser(group, "allow_hosts", metavar="HOST")
     opts.make_parser(group, "tcp_hosts", metavar="HOST")
     opts.make_parser(group, "upstream_auth", metavar="USER:PASS")
     opts.make_parser(group, "proxyauth", metavar="SPEC")
@@ -79,6 +68,7 @@ def common_options(parser, opts):
     group = parser.add_argument_group("SSL")
     opts.make_parser(group, "certs", metavar="SPEC")
     opts.make_parser(group, "ssl_insecure", short="k")
+    opts.make_parser(group, "key_size", metavar="KEY_SIZE")
 
     # Client replay
     group = parser.add_argument_group("Client Replay")
@@ -89,6 +79,7 @@ def common_options(parser, opts):
     opts.make_parser(group, "server_replay", metavar="PATH", short="S")
     opts.make_parser(group, "server_replay_kill_extra")
     opts.make_parser(group, "server_replay_nopop")
+    opts.make_parser(group, "server_replay_refresh")
 
     # Replacements
     group = parser.add_argument_group("Replacements")
