@@ -6,6 +6,7 @@ from typing import Optional, Union  # noqa
 import urwid
 
 from mitmproxy import contentviews
+from mitmproxy import ctx
 from mitmproxy import http
 from mitmproxy.tools.console import common
 from mitmproxy.tools.console import layoutwidget
@@ -37,7 +38,8 @@ class FlowViewHeader(urwid.WidgetWrap):
                 False,
                 extended=True,
                 hostheader=self.master.options.showhost,
-                max_url_len=cols,
+                cols=cols,
+                layout=self.master.options.console_flowlist_layout
             )
         else:
             self._w = urwid.Pile([])
@@ -98,11 +100,11 @@ class FlowDetails(tabs.Tabs):
             msg, body = "", [urwid.Text([("error", "[content missing]")])]
             return msg, body
         else:
-            full = self.master.commands.execute("view.getval @focus fullcontents false")
+            full = self.master.commands.execute("view.settings.getval @focus fullcontents false")
             if full == "true":
                 limit = sys.maxsize
             else:
-                limit = contentviews.VIEW_CUTOFF
+                limit = ctx.options.content_view_lines_cutoff
 
             flow_modify_cache_invalidation = hash((
                 message.raw_content,
@@ -118,7 +120,7 @@ class FlowDetails(tabs.Tabs):
         message = self._get_content_view_message
         self._get_content_view_message = None
         description, lines, error = contentviews.get_message_content_view(
-            viewmode, message
+            viewmode, message, self.flow
         )
         if error:
             self.master.log.debug(error)
