@@ -22,7 +22,12 @@ class Palette:
         'option_selected_key',
 
         # List and Connections
-        'method', 'focus',
+        'method',
+        'method_get', 'method_post', 'method_delete', 'method_other', 'method_head', 'method_put', 'method_http2_push',
+        'scheme_http', 'scheme_https', 'scheme_other',
+        'url_punctuation', 'url_domain', 'url_filename', 'url_extension', 'url_query_key', 'url_query_value',
+        'content_none', 'content_text', 'content_script', 'content_media', 'content_data', 'content_raw', 'content_other',
+        'focus',
         'code_200', 'code_300', 'code_400', 'code_500', 'code_other',
         'error', "warn", "alert",
         'header', 'highlight', 'intercept', 'replay', 'mark',
@@ -36,7 +41,8 @@ class Palette:
         # Commander
         'commander_command', 'commander_invalid', 'commander_hint'
     ]
-    high = None  # type: typing.Mapping[str, typing.Sequence[str]]
+    _fields.extend(['gradient_%02d' % i for i in range(100)])
+    high: typing.Optional[typing.Mapping[str, typing.Sequence[str]]] = None
 
     def palette(self, transparent):
         l = []
@@ -68,6 +74,27 @@ class Palette:
         return l
 
 
+def gen_gradient(palette, cols):
+    for i in range(100):
+        palette['gradient_%02d' % i] = (cols[i * len(cols) // 100], 'default')
+
+
+def gen_rgb_gradient(palette, cols):
+    parts = len(cols) - 1
+    for i in range(100):
+        p = i / 100
+        idx = int(p * parts)
+        t0 = cols[idx]
+        t1 = cols[idx + 1]
+        pp = p * parts % 1
+        t = (
+            round(t0[0] + (t1[0] - t0[0]) * pp),
+            round(t0[1] + (t1[1] - t0[1]) * pp),
+            round(t0[2] + (t1[2] - t0[2]) * pp),
+        )
+        palette['gradient_%02d' % i] = ("#%x%x%x" % t, 'default')
+
+
 class LowDark(Palette):
 
     """
@@ -95,6 +122,33 @@ class LowDark(Palette):
 
         # List and Connections
         method = ('dark cyan', 'default'),
+        method_get = ('light green', 'default'),
+        method_post = ('brown', 'default'),
+        method_delete = ('light red', 'default'),
+        method_head = ('dark cyan', 'default'),
+        method_put = ('dark red', 'default'),
+        method_other = ('dark magenta', 'default'),
+        method_http2_push = ('dark gray', 'default'),
+
+        scheme_http = ('dark cyan', 'default'),
+        scheme_https = ('dark green', 'default'),
+        scheme_other = ('dark magenta', 'default'),
+
+        url_punctuation = ('light gray', 'default'),
+        url_domain = ('white', 'default'),
+        url_filename = ('dark cyan', 'default'),
+        url_extension = ('light gray', 'default'),
+        url_query_key = ('white', 'default'),
+        url_query_value = ('light gray', 'default'),
+
+        content_none = ('dark gray', 'default'),
+        content_text = ('light gray', 'default'),
+        content_script = ('dark green', 'default'),
+        content_media = ('light blue', 'default'),
+        content_data = ('brown', 'default'),
+        content_raw = ('dark red', 'default'),
+        content_other = ('dark magenta', 'default'),
+
         focus = ('yellow', 'default'),
 
         code_200 = ('dark green', 'default'),
@@ -127,6 +181,7 @@ class LowDark(Palette):
         commander_invalid = ('light red', 'default'),
         commander_hint = ('dark gray', 'default'),
     )
+    gen_gradient(low, ['light red', 'yellow', 'light green', 'dark green', 'dark cyan', 'dark blue'])
 
 
 class Dark(LowDark):
@@ -167,6 +222,33 @@ class LowLight(Palette):
 
         # List and Connections
         method = ('dark cyan', 'default'),
+        method_get = ('dark green', 'default'),
+        method_post = ('brown', 'default'),
+        method_head = ('dark cyan', 'default'),
+        method_put = ('light red', 'default'),
+        method_delete = ('dark red', 'default'),
+        method_other = ('light magenta', 'default'),
+        method_http2_push = ('light gray', 'default'),
+
+        scheme_http = ('dark cyan', 'default'),
+        scheme_https = ('light green', 'default'),
+        scheme_other = ('light magenta', 'default'),
+
+        url_punctuation = ('dark gray', 'default'),
+        url_domain = ('dark gray', 'default'),
+        url_filename = ('black', 'default'),
+        url_extension = ('dark gray', 'default'),
+        url_query_key = ('light blue', 'default'),
+        url_query_value = ('dark blue', 'default'),
+
+        content_none = ('black', 'default'),
+        content_text = ('dark gray', 'default'),
+        content_script = ('light green', 'default'),
+        content_media = ('light blue', 'default'),
+        content_data = ('brown', 'default'),
+        content_raw = ('light red', 'default'),
+        content_other = ('light magenta', 'default'),
+
         focus = ('black', 'default'),
 
         code_200 = ('dark green', 'default'),
@@ -198,6 +280,7 @@ class LowLight(Palette):
         commander_invalid = ('light red', 'default'),
         commander_hint = ('light gray', 'default'),
     )
+    gen_gradient(low, ['light red', 'yellow', 'light green', 'dark green', 'dark cyan', 'dark blue'])
 
 
 class Light(LowLight):
@@ -256,7 +339,27 @@ class SolarizedLight(LowLight):
         option_active_selected = (sol_orange, sol_base2),
 
         # List and Connections
-        method = (sol_cyan, 'default'),
+
+        method = ('dark cyan', 'default'),
+        method_get = (sol_green, 'default'),
+        method_post = (sol_orange, 'default'),
+        method_head = (sol_cyan, 'default'),
+        method_put = (sol_red, 'default'),
+        method_delete = (sol_red, 'default'),
+        method_other = (sol_magenta, 'default'),
+        method_http2_push = ('light gray', 'default'),
+
+        scheme_http = (sol_cyan, 'default'),
+        scheme_https = ('light green', 'default'),
+        scheme_other = ('light magenta', 'default'),
+
+        url_punctuation = ('dark gray', 'default'),
+        url_domain = ('dark gray', 'default'),
+        url_filename = ('black', 'default'),
+        url_extension = ('dark gray', 'default'),
+        url_query_key = (sol_blue, 'default'),
+        url_query_value = ('dark blue', 'default'),
+
         focus = (sol_base01, 'default'),
 
         code_200 = (sol_green, 'default'),
@@ -311,9 +414,28 @@ class SolarizedDark(LowDark):
         option_active_selected = (sol_orange, sol_base00),
 
         # List and Connections
-        method = (sol_cyan, 'default'),
         focus = (sol_base1, 'default'),
 
+        method = (sol_cyan, 'default'),
+        method_get = (sol_green, 'default'),
+        method_post = (sol_orange, 'default'),
+        method_delete = (sol_red, 'default'),
+        method_head = (sol_cyan, 'default'),
+        method_put = (sol_red, 'default'),
+        method_other = (sol_magenta, 'default'),
+        method_http2_push = (sol_base01, 'default'),
+
+        url_punctuation = ('h242', 'default'),
+        url_domain = ('h252', 'default'),
+        url_filename = ('h132', 'default'),
+        url_extension = ('h96', 'default'),
+        url_query_key = ('h37', 'default'),
+        url_query_value = ('h30', 'default'),
+
+        content_none = (sol_base01, 'default'),
+        content_text = (sol_base1, 'default'),
+        content_media = (sol_blue, 'default'),
+
         code_200 = (sol_green, 'default'),
         code_300 = (sol_blue, 'default'),
         code_400 = (sol_orange, 'default',),
@@ -342,6 +464,7 @@ class SolarizedDark(LowDark):
         commander_invalid = (sol_orange, 'default'),
         commander_hint = (sol_base00, 'default'),
     )
+    gen_rgb_gradient(high, [(15, 0, 0), (15, 15, 0), (0, 15, 0), (0, 15, 15), (0, 0, 15)])
 
 
 DEFAULT = "dark"
